aboutsummaryrefslogtreecommitdiff
path: root/src/include/gnunet_psyc_service.h
diff options
context:
space:
mode:
authorGabor X Toth <*@tg-x.net>2014-03-12 16:39:41 +0000
committerGabor X Toth <*@tg-x.net>2014-03-12 16:39:41 +0000
commitdbdb091b11204e1e1caaa3f4260bb6cf1168cbd2 (patch)
tree23d24f1cd487b68d0fcb30f015c4f7f6ef9a015d /src/include/gnunet_psyc_service.h
parent1bf8c98f6d843f30e9abfa6dde31e31e50170c06 (diff)
PSYC: in-order delivery of fragments; tests for large messages
Cache message received fragments from multicast and deliver them in the correct order to clients. Test messages with large modifier and data payloads.
Diffstat (limited to 'src/include/gnunet_psyc_service.h')
-rw-r--r--src/include/gnunet_psyc_service.h17
1 files changed, 11 insertions, 6 deletions
diff --git a/src/include/gnunet_psyc_service.h b/src/include/gnunet_psyc_service.h
index 8f1707854e..3a0c713d5d 100644
--- a/src/include/gnunet_psyc_service.h
+++ b/src/include/gnunet_psyc_service.h
@@ -444,10 +444,14 @@ typedef int
* contain: "name\0value". If the whole value does not fit, subsequent
* calls to this function should write continuations of the value to
* @a data.
* @param oper Where to write the operator of the modifier. Only needed during
* the first call to this callback at the beginning of the modifier.
* In case of subsequent calls asking for value continuations @a oper is
* set to #NULL.
* @return #GNUNET_SYSERR on error (fatal, aborts transmission)
* #GNUNET_NO on success, if more data is to be transmitted later.
* Should be used if @a data_size was not big enough to take all the
@@ -461,7 +465,8 @@ typedef int
(*GNUNET_PSYC_TransmitNotifyModifier) (void *cls,
uint16_t *data_size,
void *data,
- uint8_t *oper);
+ uint8_t *oper,
+ uint32_t *value_size);
/**
* Flags for transmitting messages to a channel by the master.
@@ -659,7 +664,7 @@ GNUNET_PSYC_slave_transmit (struct GNUNET_PSYC_Slave *slave,
* @param th Handle of the request that is being resumed.
*/
void
-GNUNET_PSYC_slave_transmit_resume (struct GNUNET_PSYC_MasterTransmitHandle *th);
+GNUNET_PSYC_slave_transmit_resume (struct GNUNET_PSYC_SlaveTransmitHandle *th);
/**
@@ -444,10 +444,14 @@ typedef int
* calls to this function should write continuations of the value to
* @a data.
- * @param oper Where to write the operator of the modifier. Only needed during
- * the first call to this callback at the beginning of the modifier.
- * In case of subsequent calls asking for value continuations @a oper is
- * set to #NULL.
+ * @param[out] oper Where to write the operator of the modifier.
+ * Only needed during the first call to this callback at the beginning
+ * of the modifier. In case of subsequent calls asking for value
+ * continuations @a oper is set to #NULL.
+ * @param[out] value_size Where to write the full size of the value.
+ * Only needed during the first call to this callback at the beginning
+ * of the modifier. In case of subsequent calls asking for value
+ * continuations @a value_size is set to #NULL.
* @return #GNUNET_SYSERR on error (fatal, aborts transmission)
* #GNUNET_NO on success, if more data is to be transmitted later.